summaryrefslogtreecommitdiffstats
path: root/kalarm/kalarmapp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/kalarmapp.h')
-rw-r--r--kalarm/kalarmapp.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kalarm/kalarmapp.h b/kalarm/kalarmapp.h
index ce1787ff..0aa81b1b 100644
--- a/kalarm/kalarmapp.h
+++ b/kalarm/kalarmapp.h
@@ -48,6 +48,7 @@ class ShellProcess;
class KAlarmApp : public KUniqueApplication
{
Q_OBJECT
+ TQ_OBJECT
public:
~KAlarmApp();
virtual int newInstance();
@@ -61,7 +62,7 @@ class KAlarmApp : public KUniqueApplication
bool restoreSession();
bool sessionClosingDown() const { return mSessionClosingDown; }
void quitIf() { quitIf(0); }
- void doQuit(TQWidget* parent);
+ void doQuit(TQWidget* tqparent);
static void displayFatalError(const TQString& message);
void addWindow(TrayWindow* w) { mTrayWindow = w; }
void removeWindow(TrayWindow*);
@@ -70,13 +71,13 @@ class KAlarmApp : public KUniqueApplication
bool displayTrayIcon(bool show, MainWindow* = 0);
bool trayIconDisplayed() const { return !!mTrayWindow; }
bool editNewAlarm(MainWindow* = 0);
- virtual void commitData(QSessionManager&);
+ virtual void commitData(TQSessionManager&);
void* execAlarm(KAEvent&, const KAAlarm&, bool reschedule, bool allowDefer = true, bool noPreAction = false);
void alarmShowing(KAEvent&, KAAlarm::Type, const DateTime&);
void alarmCompleted(const KAEvent&);
bool deleteEvent(const TQString& eventID) { return handleEvent(eventID, EVENT_CANCEL); }
- void commandMessage(ShellProcess*, TQWidget* parent);
+ void commandMessage(ShellProcess*, TQWidget* tqparent);
// Methods called indirectly by the DCOP interface
bool scheduleEvent(KAEvent::Action, const TQString& text, const TQDateTime&,
int lateCancel, int flags, const TQColor& bg, const TQColor& fg,
@@ -84,7 +85,7 @@ class KAlarmApp : public KUniqueApplication
int reminderMinutes, const KARecurrence& recurrence,
int repeatInterval, int repeatCount,
uint mailFromID = 0, const EmailAddressList& mailAddresses = EmailAddressList(),
- const TQString& mailSubject = TQString::null,
+ const TQString& mailSubject = TQString(),
const TQStringList& mailAttachments = TQStringList());
bool handleEvent(const TQString& calendarFile, const TQString& eventID) { return handleEvent(calendarFile, eventID, EVENT_HANDLE); }
bool triggerEvent(const TQString& calendarFile, const TQString& eventID) { return handleEvent(calendarFile, eventID, EVENT_TRIGGER); }
@@ -130,11 +131,11 @@ class KAlarmApp : public KUniqueApplication
TQStringList tempFiles;
int flags;
};
- struct DcopQEntry
+ struct DcopTQEntry
{
- DcopQEntry(EventFunc f, const TQString& id) : function(f), eventId(id) { }
- DcopQEntry(const KAEvent& e, EventFunc f = EVENT_HANDLE) : function(f), event(e) { }
- DcopQEntry() { }
+ DcopTQEntry(EventFunc f, const TQString& id) : function(f), eventId(id) { }
+ DcopTQEntry(const KAEvent& e, EventFunc f = EVENT_HANDLE) : function(f), event(e) { }
+ DcopTQEntry() { }
EventFunc function;
TQString eventId;
KAEvent event;
@@ -159,16 +160,16 @@ class KAlarmApp : public KUniqueApplication
static int mFatalError; // a fatal error has occurred - just wait to exit
static TQString mFatalMessage; // fatal error message to output
bool mInitialised; // initialisation complete: ready to handle DCOP calls
- DcopHandler* mDcopHandler; // the parent of the main DCOP receiver object
+ DcopHandler* mDcopHandler; // the tqparent of the main DCOP receiver object
#ifdef OLD_DCOP
- DcopHandlerOld* mDcopHandlerOld; // the parent of the old main DCOP receiver object
+ DcopHandlerOld* mDcopHandlerOld; // the tqparent of the old main DCOP receiver object
#endif
TrayWindow* mTrayWindow; // active system tray icon
TQTime mStartOfDay; // start-of-day time currently in use
TQColor mPrefsExpiredColour; // expired alarms text colour
int mPrefsExpiredKeepDays;// how long expired alarms are being kept
TQValueList<ProcData*> mCommandProcesses; // currently active command alarm processes
- TQValueList<DcopQEntry> mDcopQueue; // DCOP command queue
+ TQValueList<DcopTQEntry> mDcopQueue; // DCOP command queue
int mPendingQuitCode; // exit code for a pending quit
bool mPendingQuit; // quit once the DCOP command and shell command queues have been processed
bool mProcessingQueue; // a mDcopQueue entry is currently being processed